@@ -1,10 +1,10 @@
 use std::intrinsics::transmute;
 
-use widestring::U16Str;
-
 use crate::{
-    borrow_mut_statement::BorrowMutStatement, handles::Statement, parameter::Blob, CursorImpl,
-    Error, ParameterRefCollection,
+    borrow_mut_statement::BorrowMutStatement,
+    handles::{SqlText, Statement},
+    parameter::Blob,
+    CursorImpl, Error, ParameterRefCollection,
 };
 
 /// Shared implementation for executing a query with parameters between [`crate::Connection`],
@@ -20,7 +20,7 @@ use crate::{
 /// * `params`: The parameters bound to the statement before query execution.
 pub fn execute_with_parameters<S>(
     lazy_statement: impl FnOnce() -> Result<S, Error>,
-    query: Option<&U16Str>,
+    query: Option<&SqlText>,
     mut params: impl ParameterRefCollection,
 ) -> Result<Option<CursorImpl<S>>, Error>
 where
@@ -53,7 +53,7 @@ where
 /// * Furthermore all bound delayed parameters must be of type `*mut &mut dyn Blob`.
 pub unsafe fn execute<S>(
     mut statement: S,
-    query: Option<&U16Str>,
+    query: Option<&SqlText>,
 ) -> Result<Option<CursorImpl<S>>, Error>
 where
     S: BorrowMutStatement,
@@ -93,10 +93,10 @@ where
 /// [`crate::Preallocated`].
 pub fn execute_columns<S>(
     mut statement: S,
-    catalog_name: &U16Str,
-    schema_name: &U16Str,
-    table_name: &U16Str,
-    column_name: &U16Str,
+    catalog_name: &SqlText,
+    schema_name: &SqlText,
+    table_name: &SqlText,
+    column_name: &SqlText,
 ) -> Result<CursorImpl<S>, Error>
 where
     S: BorrowMutStatement,
@@ -118,10 +118,10 @@ where
 /// [`crate::Preallocated`].
 pub fn execute_tables<S>(
     mut statement: S,
-    catalog_name: Option<&U16Str>,
-    schema_name: Option<&U16Str>,
-    table_name: Option<&U16Str>,
-    column_name: Option<&U16Str>,
+    catalog_name: &SqlText,
+    schema_name: &SqlText,
+    table_name: &SqlText,
+    column_name: &SqlText,
 ) -> Result<CursorImpl<S>, Error>
 where
     S: BorrowMutStatement,
